==> spawn-lia-0.1.7.tar.gz: spawn-lia-0.1.7/README.md <==
# lia

[![Downloads](https://static.pepy.tech/personalized-badge/spawn-lia?period=total&units=international_system&left_color=black&right_color=orange&left_text=Downloads)](https://pepy.tech/project/spawn-lia)
[![License: GPL v3](https://img.shields.io/badge/License-GPL_v3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0)
![Python Versions](https://img.shields.io/badge/python-3.8%20%7C%203.9%20%7C%203.10%20%7C%203.11%20%7C%20-blue) 
![Style Black](https://warehouse-camo.ingress.cmh1.psfhosted.org/fbfdc7754183ecf079bc71ddeabaf88f6cbc5c00/68747470733a2f2f696d672e736869656c64732e696f2f62616467652f636f64652532307374796c652d626c61636b2d3030303030302e737667) 


[![PyPI - Version](https://img.shields.io/pypi/v/spawn-lia.svg)](https://pypi.org/project/spawn-lia)

![Lia](lia.jpg)

-----

**Table of Contents**

- [Why?](#why)
- [What?](#what)
- [Lia](#lia)
- [Installation](#installation)
- [Usage](#usage)

## Why? 

Remember code is poetry. And we write out own story. And for this, we need a support.

Without a support, all your efforts will fail. A support takes care we do all the necessary things we would not find time during battles. We need a support. So we asked `lia` to join us. 

She protects us from malicious adversaries, and heals our organization by making our poetry better and thereby our story. 

## What?

`lia` is the best support you can hope for. She helps us to maintain our ship, fight enemies, and win customers. 

## Lia

Why did we name the package `lia`?

As a short form of Elisabeth, Lia means "God is fullness", "God is my oath" or "God swears". From Amilia Lia gets the meanings "the zealous", "the imitator" or "the competitor" and from Julia "from the family of the Julii" or "consecrated to Jupiter". Lia is also the Irish word for "healer".

All other meanings do not matter in this context whatsoever. 

In fact, the name is so similar to `lua` a common language for creating cyber weapons that altering the name into something more beautiful pays attention to the fact that `lia` is doing more or less the exact opposite of `lua`. 

Also check the movie [Warcraft](https://www.imdb.com/title/tt0803096/) for background information about the story. It is going on for some time now. But we decided to not just sit still since the world became full of war recently. Thats why we will grow into our predestined roles. Its destiny. 

You can't avoid destiny. It is even waste of time trying to. Surrendering is a proven method for manifestation. You probably know that anyways. 

We are excited what the future has prepared for us.

## Installation

```bash
pip install spawn-lia
```
If you want to get really fancy (it really makes a lot more fun) create an alias for `pip install`

```bash
nano ~/.bashrc
```
And append 

```bash 
alias cast='pip install'
```
After saving run 
```bash
source ~/.bashrc
```
Then finally, 

```bash
cast spawn-lia
```

## Usage

To improve the quality of your package and doing local ci do:

```bash
lia heal package
```

To deploy you package do 

```bash
lia deploy package 
```

==> spawn-lia-0.1.9.tar.gz: spawn-lia-0.1.9/README.md <==
# lia

[![Downloads](https://static.pepy.tech/personalized-badge/spawn-lia?period=total&units=international_system&left_color=black&right_color=orange&left_text=Downloads)](https://pepy.tech/project/spawn-lia)
[![License: GPL v3](https://img.shields.io/badge/License-GPL_v3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0)
![Python Versions](https://img.shields.io/badge/python-3.8%20%7C%203.9%20%7C%203.10%20%7C%203.11%20%7C%20-blue) 
![Style Black](https://warehouse-camo.ingress.cmh1.psfhosted.org/fbfdc7754183ecf079bc71ddeabaf88f6cbc5c00/68747470733a2f2f696d672e736869656c64732e696f2f62616467652f636f64652532307374796c652d626c61636b2d3030303030302e737667) 


[![PyPI - Version](https://img.shields.io/pypi/v/spawn-lia.svg)](https://pypi.org/project/spawn-lia)

![Lia](lia.jpg)

-----

**Table of Contents**

- [Why?](#why)
- [What?](#what)
- [Lia](#lia)
- [Installation](#installation)
- [Usage](#usage)

## Why? 

Remember code is poetry. And we write out own story. And for this, we need a support.

Without a support, all your efforts will fail. A support takes care we do all the necessary things we would not find time during battles. We need a support. So we asked `lia` to join us. 

She protects us from malicious adversaries, and heals our organization by making our poetry better and thereby our story. 

## What?

`lia` is the best support you can hope for. She helps us to maintain our ship, fight enemies, and win customers. 

## Lia

Why did we name the package `lia`?

As a short form of Elisabeth, Lia means "God is fullness", "God is my oath" or "God swears". From Amilia Lia gets the meanings "the zealous", "the imitator" or "the competitor" and from Julia "from the family of the Julii" or "consecrated to Jupiter". Lia is also the Irish word for "healer".

All other meanings do not matter in this context whatsoever. 

In fact, the name is so similar to `lua` a common language for creating cyber weapons that altering the name into something more beautiful pays attention to the fact that `lia` is doing more or less the exact opposite of `lua`. 

Also check the movie [Warcraft](https://www.imdb.com/title/tt0803096/) for background information about the story. It is going on for some time now. But we decided to not just sit still since the world became full of war recently. Thats why we will grow into our predestined roles. Its destiny. 

You can't avoid destiny. It is even waste of time trying to. Surrendering is a proven method for manifestation. You probably know that anyways. 

We are excited what the future has prepared for us.

## Installation

```bash
pip install spawn-lia
```
If you want to get really fancy (it really makes a lot more fun) create an alias for `pip install`

```bash
nano ~/.bashrc
```
And append 

```bash 
alias cast='pip install'
```
After saving run 
```bash
source ~/.bashrc
```
Then finally, 

```bash
cast spawn-lia
```

## Usage

To improve the quality of your package and doing local CI do:

```bash
lia heal package
```
Do not be afraid you will probably see many errors. This behavior is intended and shall raise your attention to all sorts of errors, bugs, technical debt and antipatterns in your code. 

Getting rid of everything may be tedious but it is doable. We are going through the same process. It improved everything for us.

If you need more information about typing, then the `mypy` [documentation](https://mypy.readthedocs.io/en/stable/getting_started.html) is a great place to start. 


To deploy you package do 

```bash
lia deploy package 
```
